@@ -34,38 +34,38 @@ admin.autodiscover()
 # Root URL patterns
 urlpatterns = patterns(
     '',
-    url(r'^' + settings.APP_URL_PREFIX + r'$',
+    url(r'^$',
         index,
         name='lava.home'),
-    url(r'^' + settings.APP_URL_PREFIX + r'me/$',
+    url(r'^me/$',
         me,
         name='lava.me'),
-    url(r'^' + settings.APP_URL_PREFIX + r'version/$',
+    url(r'^version/$',
         version,
         name='lava.version_details'),
-    url(r'^' + settings.APP_URL_PREFIX + r'accounts/',
+    url(r'^accounts/',
         include('django.contrib.auth.urls')),
-    url(r'^' + settings.APP_URL_PREFIX + r'admin/',
+    url(r'^admin/',
         include(admin.site.urls)),
-    url(r'^' + settings.APP_URL_PREFIX + r'openid/',
+    url(r'^openid/',
         include('django_openid_auth.urls')),
-    url(r'^' + settings.APP_URL_PREFIX + r'RPC2/',
+    url(r'^RPC2/',
         'linaro_django_xmlrpc.views.handler',
         name='lava.api_handler',
         kwargs={
             'mapper': loader.xmlrpc_mapper,
             'help_view': 'lava.api_help'}),
-    url(r'^' + settings.APP_URL_PREFIX + r'api/help/$',
+    url(r'^api/help/$',
         'linaro_django_xmlrpc.views.help',
         name='lava.api_help',
         kwargs={
             'mapper': loader.xmlrpc_mapper}),
-    url(r'^' + settings.APP_URL_PREFIX + r'api/',
+    url(r'^api/',
         include(api_urls.token_urlpatterns)),
     # XXX: This is not needed but without it linaro-django-xmlrpc tests fail
-    url(r'^' + settings.APP_URL_PREFIX + r'api/',
+    url(r'^api/',
         include(api_urls.default_mapper_urlpatterns)),
-    url(r'^' + settings.APP_URL_PREFIX + r'utils/markitup/',
+    url(r'^utils/markitup/',
         include('lava_markitup.urls')))
 
 
